@@ -1,6 +1,6 @@
 # Natural Language Toolkit: WordNet Browser Application
 #
-# Copyright (C) 2001-2022 NLTK Project
+# Copyright (C) 2001-2025 NLTK Project
 # Author: Jussi Salmela <jtsalmela@users.sourceforge.net>
 #         Paul Bone <pbone@students.csse.unimelb.edu.au>
 # URL: <https://www.nltk.org/>
@@ -47,11 +47,10 @@ Options::
 
 import base64
 import copy
-import datetime
 import getopt
+import io
 import os
 import pickle
-import re
 import sys
 import threading
 import time
@@ -60,17 +59,12 @@ from collections import defaultdict
 from http.server import BaseHTTPRequestHandler, HTTPServer
 
 # Allow this program to run inside the NLTK source tree.
-from sys import argv, path
+from sys import argv
 from urllib.parse import unquote_plus
 
 from nltk.corpus import wordnet as wn
 from nltk.corpus.reader.wordnet import Lemma, Synset
 
-# now included in local file
-# from util import html_header, html_trailer, \
-#    get_static_index_page, get_static_page_by_path, \
-#    page_from_word, page_from_href
-
 firstClient = True
 
 # True if we're not also running a web browser.  The value f server_mode
@@ -127,7 +121,12 @@ class MyServerHandler(BaseHTTPRequestHandler):
             else:
                 # Handle files here.
                 word = sp
-                page = get_static_page_by_path(usp)
+                try:
+                    page = get_static_page_by_path(usp)
+                except FileNotFoundError:
+                    page = "Internal error: Path for static page '%s' is unknown" % usp
+                    # Set type to plain to prevent XSS by printing the path as HTML
+                    type = "text/plain"
         elif sp.startswith("search"):
             # This doesn't seem to work with MWEs.
             type = "text/html"
@@ -282,6 +281,7 @@ This provides a backend to both wxbrowse and browserver.py.
 # Main logic for wordnet browser.
 #
 
+
 # This is wrapped inside a function since wn is only available if the
 # WordNet corpus is installed.
 def _pos_tuples():
@@ -414,7 +414,7 @@ def get_relations_data(word, synset):
                 ),
             ),
         )
-    elif synset.pos() == wn.ADJ or synset.pos == wn.ADJ_SAT:
+    elif synset.pos() == wn.ADJ or synset.pos() == wn.ADJ_SAT:
         return (
             (ANTONYM, "Antonym", lemma_property(word, synset, lambda l: l.antonyms())),
             (SIMILAR, "Similar to", synset.similar_tos()),
@@ -435,7 +435,7 @@ def get_relations_data(word, synset):
         )
         # Derived from adjective - not supported by corpus
     else:
-        raise TypeError("Unhandles synset POS type: " + str(synset.pos()))
+        raise TypeError("Unhandled synset POS type: " + str(synset.pos()))
 
 
 html_header = """
@@ -654,6 +654,16 @@ def _synset_relations(word, synset, synset_relations):
     return html
 
 
+class RestrictedUnpickler(pickle.Unpickler):
+    """
+    Unpickler that prevents any class or function from being used during loading.
+    """
+
+    def find_class(self, module, name):
+        # Forbid every function
+        raise pickle.UnpicklingError(f"global '{module}.{name}' is forbidden")
+
+
 class Reference:
     """
     A reference to a page that may be generated by page_word
@@ -689,7 +699,7 @@ class Reference:
         Decode a reference encoded with Reference.encode
         """
         string = base64.urlsafe_b64decode(string.encode())
-        word, synset_relations = pickle.loads(string)
+        word, synset_relations = RestrictedUnpickler(io.BytesIO(string)).load()
         return Reference(word, synset_relations)
 
     def toggle_synset_relation(self, synset, relation):
@@ -789,7 +799,7 @@ def page_from_reference(href):
                 except KeyError:
                     pass
     if not body:
-        body = "The word or words '%s' where not found in the dictionary." % word
+        body = "The word or words '%s' were not found in the dictionary." % word
     return body, word
 
 
@@ -816,8 +826,7 @@ def get_static_page_by_path(path):
         return get_static_web_help_page()
     elif path == "wx_help.html":
         return get_static_wx_help_page()
-    else:
-        return "Internal error: Path for static page '%s' is unknown" % path
+    raise FileNotFoundError()
 
 
 def get_static_web_help_page():
@@ -828,7 +837,7 @@ def get_static_web_help_page():
 <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
 <html>
      <!-- Natural Language Toolkit: Wordnet Interface: Graphical Wordnet Browser
-            Copyright (C) 2001-2022 NLTK Project
+            Copyright (C) 2001-2025 NLTK Project
             Author: Jussi Salmela <jtsalmela@users.sourceforge.net>
             URL: <https://www.nltk.org/>
             For license information, see LICENSE.TXT -->
@@ -898,7 +907,7 @@ def get_static_index_page(with_shutdown):
 <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Frameset//EN"  "http://www.w3.org/TR/html4/frameset.dtd">
 <HTML>
      <!-- Natural Language Toolkit: Wordnet Interface: Graphical Wordnet Browser
-            Copyright (C) 2001-2022 NLTK Project
+            Copyright (C) 2001-2025 NLTK Project
             Author: Jussi Salmela <jtsalmela@users.sourceforge.net>
             URL: <https://www.nltk.org/>
             For license information, see LICENSE.TXT -->
@@ -931,7 +940,7 @@ def get_static_upper_page(with_shutdown):
 <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
 <html>
     <!-- Natural Language Toolkit: Wordnet Interface: Graphical Wordnet Browser
-        Copyright (C) 2001-2022 NLTK Project
+        Copyright (C) 2001-2025 NLTK Project
         Author: Jussi Salmela <jtsalmela@users.sourceforge.net>
         URL: <https://www.nltk.org/>
         For license information, see LICENSE.TXT -->
@@ -975,7 +984,7 @@ def app():
     server_mode = False
     help_mode = False
     logfilename = None
-    for (opt, value) in opts:
+    for opt, value in opts:
         if (opt == "-l") or (opt == "--logfile"):
             logfilename = str(value)
         elif (opt == "-p") or (opt == "--port"):
