@@ -1,6 +1,6 @@
 # Natural Language Toolkit: CCG Categories
 #
-# Copyright (C) 2001-2022 NLTK Project
+# Copyright (C) 2001-2025 NLTK Project
 # Author: Graeme Gange <ggange@csse.unimelb.edu.au>
 # URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
@@ -125,7 +125,7 @@ class CCGVar(AbstractCCGCategory):
         """If there is a substitution corresponding to this variable,
         return the substituted category.
         """
-        for (var, cat) in substitutions:
+        for var, cat in substitutions:
             if var == self:
                 return cat
         return self
@@ -197,7 +197,7 @@ class Direction:
         if not self.is_variable():
             return self
 
-        for (var, restrs) in subs:
+        for var, restrs in subs:
             if var == "_":
                 return Direction(self._dir, restrs)
         return self
