@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Compatibility
 #
-# Copyright (C) 2001-2022 NLTK Project
+# Copyright (C) 2001-2025 NLTK Project
 #
 # URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
@@ -12,12 +12,7 @@ from functools import wraps
 
 # The following datasets have a /PY3 subdirectory containing
 # a full copy of the data which has been re-encoded or repickled.
-DATA_UPDATES = [
-    ("chunkers", "maxent_ne_chunker"),
-    ("help", "tagsets"),
-    ("taggers", "maxent_treebank_pos_tagger"),
-    ("tokenizers", "punkt"),
-]
+DATA_UPDATES = []
 
 _PY3_DATA_UPDATES = [os.path.join(*path_list) for path_list in DATA_UPDATES]
 
