@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Comparative Sentence Corpus Reader
 #
-# Copyright (C) 2001-2022 NLTK Project
+# Copyright (C) 2001-2025 NLTK Project
 # Author: Pierpaolo Pantone <24alsecondo@gmail.com>
 # URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
@@ -249,7 +249,7 @@ class ComparativeSentencesCorpusReader(CorpusReader):
                         line = stream.readline()
                         entities_feats = ENTITIES_FEATS.findall(line)
                         if entities_feats:
-                            for (code, entity_feat) in entities_feats:
+                            for code, entity_feat in entities_feats:
                                 if code == "1":
                                     comparison.entity_1 = entity_feat.strip()
                                 elif code == "2":
