@@ -1,7 +1,8 @@
 # Natural Language Toolkit: Utility functions
 #
-# Copyright (C) 2001-2022 NLTK Project
+# Copyright (C) 2001-2025 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
+# Author: ekaf (Restricting and switching pickles)
 # URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
@@ -9,8 +10,8 @@
 Functions to find and load NLTK resource files, such as corpora,
 grammars, and saved processing objects.  Resource files are identified
 using URLs, such as ``nltk:corpora/abc/rural.txt`` or
-``http://nltk.org/sample/toy.cfg``.  The following URL protocols are
-supported:
+``https://raw.githubusercontent.com/nltk/nltk/develop/nltk/test/toy.cfg``.
+The following URL protocols are supported:
 
   - ``file:path``: Specifies the file whose path is *path*.
     Both relative and absolute paths may be used.
@@ -51,7 +52,6 @@ except ImportError:
     from zlib import Z_FINISH as FLUSH
 
 from nltk import grammar, sem
-from nltk.compat import add_py3_data, py3_data
 from nltk.internals import deprecated
 
 textwrap_indent = functools.partial(textwrap.indent, prefix="  ")
@@ -299,7 +299,6 @@ class FileSystemPathPointer(PathPointer, str):
     directly via a given absolute path.
     """
 
-    @py3_data
     def __init__(self, _path):
         """
         Create a new path pointer for the given absolute path.
@@ -348,7 +347,6 @@ class BufferedGzipFile(GzipFile):
     Python versions.
     """
 
-    @py3_data
     def __init__(
         self, filename=None, mode=None, compresslevel=9, fileobj=None, **kwargs
     ):
@@ -381,7 +379,6 @@ class ZipFilePathPointer(PathPointer):
     which can be accessed by reading that zipfile.
     """
 
-    @py3_data
     def __init__(self, zipfile, entry=""):
         """
         Create a new path pointer pointing at the specified entry
@@ -395,7 +392,6 @@ class ZipFilePathPointer(PathPointer):
 
         # Check that the entry exists:
         if entry:
-
             # Normalize the entry string, it should be relative:
             entry = normalize_resource_name(entry, True, "/").lstrip("/")
 
@@ -659,6 +655,82 @@ AUTO_FORMATS = {
 }
 
 
+def restricted_pickle_load(string):
+    """
+    Prevents any class or function from loading.
+    """
+    from nltk.app.wordnet_app import RestrictedUnpickler
+
+    return RestrictedUnpickler(BytesIO(string)).load()
+
+
+def switch_punkt(lang="english"):
+    """
+    Return a pickle-free Punkt tokenizer instead of loading a pickle.
+
+    >>> import nltk
+    >>> tokenizer = nltk.data.load('tokenizers/punkt/english.pickle')
+    >>> print(tokenizer.tokenize("Hello! How are you?"))
+    ['Hello!', 'How are you?']
+    """
+    from nltk.tokenize import PunktTokenizer as tok
+
+    return tok(lang)
+
+
+def switch_chunker(fmt="multiclass"):
+    """
+    Return a pickle-free Named Entity Chunker instead of loading a pickle.
+
+    >>> import nltk
+    >>> from nltk.corpus import treebank
+    >>> from pprint import pprint
+    >>> chunker = nltk.data.load('chunkers/maxent_ne_chunker/PY3/english_ace_multiclass.pickle')
+    >>> pprint(chunker.parse(treebank.tagged_sents()[2][8:14])) # doctest: +NORMALIZE_WHITESPACE
+    Tree('S', [('chairman', 'NN'), ('of', 'IN'), Tree('ORGANIZATION', [('Consolidated', 'NNP'), ('Gold', 'NNP'), ('Fields', 'NNP')]), ('PLC', 'NNP')])
+
+    """
+    from nltk.chunk import ne_chunker
+
+    return ne_chunker(fmt)
+
+
+def switch_t_tagger():
+    """
+    Return a pickle-free Treebank Pos Tagger instead of loading a pickle.
+
+    >>> import nltk
+    >>> from nltk.tokenize import word_tokenize
+    >>> tagger = nltk.data.load('taggers/maxent_treebank_pos_tagger/PY3/english.pickle')
+    >>> print(tagger.tag(word_tokenize("Hello, how are you?")))
+    [('Hello', 'NNP'), (',', ','), ('how', 'WRB'), ('are', 'VBP'), ('you', 'PRP'), ('?', '.')]
+
+    """
+    from nltk.classify.maxent import maxent_pos_tagger
+
+    return maxent_pos_tagger()
+
+
+def switch_p_tagger(lang):
+    """
+    Return a pickle-free Averaged Perceptron Tagger instead of loading a pickle.
+
+    >>> import nltk
+    >>> from nltk.tokenize import word_tokenize
+    >>> tagger = nltk.data.load('taggers/averaged_perceptron_tagger/averaged_perceptron_tagger.pickle')
+    >>> print(tagger.tag(word_tokenize("Hello, how are you?")))
+    [('Hello', 'NNP'), (',', ','), ('how', 'WRB'), ('are', 'VBP'), ('you', 'PRP'), ('?', '.')]
+
+    """
+    from nltk.tag import _get_tagger
+
+    if lang == "ru":
+        lang = "rus"
+    else:
+        lang = None
+    return _get_tagger(lang)
+
+
 def load(
     resource_url,
     format="auto",
@@ -715,7 +787,6 @@ def load(
     :param encoding: the encoding of the input; only used for text formats.
     """
     resource_url = normalize_resource_url(resource_url)
-    resource_url = add_py3_data(resource_url)
 
     # Determine the format of the resource.
     if format == "auto":
@@ -742,6 +813,21 @@ def load(
                 print(f"<<Using cached copy of {resource_url}>>")
             return resource_val
 
+    protocol, path_ = split_resource_url(resource_url)
+
+    if path_[-7:] == ".pickle":
+        if verbose:
+            print(f"<<Loading pickle-free alternative to {resource_url}>>")
+        fil = os.path.split(path_[:-7])[-1]
+        if path_.startswith("tokenizers/punkt"):
+            return switch_punkt(fil)
+        elif path_.startswith("chunkers/maxent_ne_chunker"):
+            return switch_chunker(fil.split("_")[-1])
+        elif path_.startswith("taggers/maxent_treebank_pos_tagger"):
+            return switch_t_tagger()
+        elif path_.startswith("taggers/averaged_perceptron_tagger"):
+            return switch_p_tagger(fil.split("_")[-1])
+
     # Let the user know what's going on.
     if verbose:
         print(f"<<Loading {resource_url}>>")
@@ -752,7 +838,7 @@ def load(
     if format == "raw":
         resource_val = opened_resource.read()
     elif format == "pickle":
-        resource_val = pickle.load(opened_resource)
+        resource_val = restricted_pickle_load(opened_resource.read())
     elif format == "json":
         import json
 
@@ -887,7 +973,7 @@ def _open(resource_url):
 
 
 class LazyLoader:
-    @py3_data
+
     def __init__(self, _path):
         self._path = _path
 
@@ -928,7 +1014,6 @@ class OpenOnDemandZipFile(zipfile.ZipFile):
     read-only (i.e. ``write()`` and ``writestr()`` are disabled.
     """
 
-    @py3_data
     def __init__(self, filename):
         if not isinstance(filename, str):
             raise TypeError("ReopenableZipFile filename must be a string")
@@ -985,7 +1070,6 @@ class SeekableUnicodeStreamReader:
 
     DEBUG = True  # : If true, then perform extra sanity checks.
 
-    @py3_data
     def __init__(self, stream, encoding, errors="strict"):
         # Rewind the stream to its beginning.
         stream.seek(0)
@@ -1411,7 +1495,7 @@ class SeekableUnicodeStreamReader:
             self.stream.seek(0)
 
             # Check for each possible BOM.
-            for (bom, new_encoding) in bom_info:
+            for bom, new_encoding in bom_info:
                 if bytes.startswith(bom):
                     if new_encoding:
                         self.encoding = new_encoding
