@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Table widget
 #
-# Copyright (C) 2001-2022 NLTK Project
+# Copyright (C) 2001-2025 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 # URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
@@ -193,7 +193,7 @@ class MultiListbox(Frame):
         x1 = event.x + event.widget.winfo_x()
         x2 = lb.winfo_x() + lb.winfo_width()
 
-        lb["width"] = max(3, lb["width"] + (x1 - x2) // charwidth)
+        lb["width"] = max(3, int(lb["width"] + (x1 - x2) // charwidth))
 
     def _resize_column_buttonrelease_cb(self, event):
         event.widget.unbind("<ButtonRelease-%d>" % event.num)
@@ -306,7 +306,7 @@ class MultiListbox(Frame):
                 >>> mlb.configure(listbox_foreground='red')  # doctest: +SKIP
         """
         cnf = dict(list(cnf.items()) + list(kw.items()))
-        for (key, val) in list(cnf.items()):
+        for key, val in list(cnf.items()):
             if key.startswith("label_") or key.startswith("label-"):
                 for label in self._labels:
                     label.configure({key[6:]: val})
@@ -341,7 +341,7 @@ class MultiListbox(Frame):
         lb = self._listboxes[col_index]
 
         cnf = dict(list(cnf.items()) + list(kw.items()))
-        for (key, val) in list(cnf.items()):
+        for key, val in list(cnf.items()):
             if key in (
                 "background",
                 "bg",
@@ -382,7 +382,7 @@ class MultiListbox(Frame):
                     "rows should be tuples whose length "
                     "is equal to the number of columns"
                 )
-        for (lb, elts) in zip(self._listboxes, list(zip(*rows))):
+        for lb, elts in zip(self._listboxes, list(zip(*rows))):
             lb.insert(index, *elts)
 
     def get(self, first, last=None):
@@ -1130,6 +1130,7 @@ class Table:
 # Demo/Test Function
 ######################################################################
 
+
 # update this to use new WordNet API
 def demo():
     root = Tk()
