@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Interface to the Prover9 Theorem Prover
 #
-# Copyright (C) 2001-2022 NLTK Project
+# Copyright (C) 2001-2025 NLTK Project
 # Author: Dan Garrette <dhgarrette@gmail.com>
 #         Ewan Klein <ewan@inf.ed.ac.uk>
 #
@@ -408,7 +408,6 @@ class Prover9LimitExceededException(Prover9Exception):
 
 
 def test_config():
-
     a = Expression.fromstring("(walk(j) & sing(j))")
     g = Expression.fromstring("walk(j)")
     p = Prover9Command(g, assumptions=[a])
@@ -433,7 +432,7 @@ def test_prove(arguments):
     """
     Try some proofs and exhibit the results.
     """
-    for (goal, assumptions) in arguments:
+    for goal, assumptions in arguments:
         g = Expression.fromstring(goal)
         alist = [Expression.fromstring(a) for a in assumptions]
         p = Prover9Command(g, assumptions=alist).prove()
