@@ -1,13 +1,13 @@
 # Natural Language Toolkit: Interface to the CoreNLP REST API.
 #
-# Copyright (C) 2001-2022 NLTK Project
+# Copyright (C) 2001-2025 NLTK Project
 # Author: Dmitrijs Milajevs <dimazest@gmail.com>
 #
 # URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 import json
-import os  # required for doctests
+import os
 import re
 import socket
 import time
@@ -38,7 +38,6 @@ def try_port(port=0):
 
 
 class CoreNLPServer:
-
     _MODEL_JAR_PATTERN = r"stanford-corenlp-(\d+)\.(\d+)\.(\d+)-models\.jar"
     _JAR = r"stanford-corenlp-(\d+)\.(\d+)\.(\d+)\.jar"
 
@@ -51,7 +50,6 @@ class CoreNLPServer:
         corenlp_options=None,
         port=None,
     ):
-
         if corenlp_options is None:
             corenlp_options = ["-preload", "tokenize,ssplit,pos,lemma,parse,depparse"]
 
@@ -346,7 +344,7 @@ class GenericCoreNLPParser(ParserI, TokenizerI, TaggerI):
             for token in sentence["tokens"]:
                 yield token["originalText"] or token["word"]
 
-    def tag_sents(self, sentences):
+    def tag_sents(self, sentences, properties=None):
         """
         Tag multiple sentences.
 
@@ -357,11 +355,16 @@ class GenericCoreNLPParser(ParserI, TokenizerI, TaggerI):
         :type sentences: list(list(str))
         :rtype: list(list(tuple(str, str))
         """
+
         # Converting list(list(str)) -> list(str)
         sentences = (" ".join(words) for words in sentences)
-        return [sentences[0] for sentences in self.raw_tag_sents(sentences)]
 
-    def tag(self, sentence: str) -> List[Tuple[str, str]]:
+        if properties is None:
+            properties = {"tokenize.whitespace": "true", "ner.useSUTime": "false"}
+
+        return [sentences[0] for sentences in self.raw_tag_sents(sentences, properties)]
+
+    def tag(self, sentence: str, properties=None) -> List[Tuple[str, str]]:
         """
         Tag a list of tokens.
 
@@ -390,9 +393,9 @@ class GenericCoreNLPParser(ParserI, TokenizerI, TaggerI):
         ('unladen', 'JJ'), ('swallow', 'VB'), ('?', '.')]
         >>> server.stop()
         """
-        return self.tag_sents([sentence])[0]
+        return self.tag_sents([sentence], properties)[0]
 
-    def raw_tag_sents(self, sentences):
+    def raw_tag_sents(self, sentences, properties=None):
         """
         Tag multiple sentences.
 
@@ -406,9 +409,13 @@ class GenericCoreNLPParser(ParserI, TokenizerI, TaggerI):
             "ssplit.isOneSentence": "true",
             "annotators": "tokenize,ssplit,",
         }
+        default_properties.update(properties or {})
 
         # Supports only 'pos' or 'ner' tags.
-        assert self.tagtype in ["pos", "ner"]
+        assert self.tagtype in [
+            "pos",
+            "ner",
+        ], "CoreNLP tagger supports only 'pos' or 'ner' tags."
         default_properties["annotators"] += self.tagtype
         for sentence in sentences:
             tagged_data = self.api_call(sentence, properties=default_properties)
@@ -767,7 +774,6 @@ class CoreNLPDependencyParser(GenericCoreNLPParser):
     parser_annotator = "depparse"
 
     def make_tree(self, result):
-
         return DependencyGraph(
             (
                 " ".join(n_items[1:])  # NLTK expects an iterable of strings...
@@ -779,7 +785,6 @@ class CoreNLPDependencyParser(GenericCoreNLPParser):
 
 def transform(sentence):
     for dependency in sentence["basicDependencies"]:
-
         dependent_index = dependency["dependent"]
         token = sentence["tokens"][dependent_index - 1]
 
