@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Probability and Statistics
 #
-# Copyright (C) 2001-2022 NLTK Project
+# Copyright (C) 2001-2025 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 #         Steven Bird <stevenbird1@gmail.com> (additions)
 #         Trevor Cohn <tacohn@cs.mu.oz.au> (additions)
@@ -245,7 +245,7 @@ class FreqDist(Counter):
         return self.most_common(1)[0][0]
 
     def plot(
-        self, *args, title="", cumulative=False, percents=False, show=True, **kwargs
+        self, *args, title="", cumulative=False, percents=False, show=False, **kwargs
     ):
         """
         Plot samples from the frequency distribution
@@ -719,7 +719,7 @@ class DictionaryProbDist(ProbDistI):
                     for x in prob_dict:
                         self._prob_dict[x] = logp
                 else:
-                    for (x, p) in self._prob_dict.items():
+                    for x, p in self._prob_dict.items():
                         self._prob_dict[x] -= value_sum
             else:
                 value_sum = sum(self._prob_dict.values())
@@ -729,7 +729,7 @@ class DictionaryProbDist(ProbDistI):
                         self._prob_dict[x] = p
                 else:
                     norm_factor = 1.0 / value_sum
-                    for (x, p) in self._prob_dict.items():
+                    for x, p in self._prob_dict.items():
                         self._prob_dict[x] *= norm_factor
 
     def prob(self, sample):
@@ -1444,7 +1444,7 @@ class SimpleGoodTuringProbDist(ProbDistI):
         xy_cov = x_var = 0.0
         x_mean = sum(log_r) / len(log_r)
         y_mean = sum(log_zr) / len(log_zr)
-        for (x, y) in zip(log_r, log_zr):
+        for x, y in zip(log_r, log_zr):
             xy_cov += (x - x_mean) * (y - y_mean)
             x_var += (x - x_mean) ** 2
         self._slope = xy_cov / x_var if x_var != 0 else 0.0
@@ -1891,7 +1891,7 @@ class ConditionalFreqDist(defaultdict):
         defaultdict.__init__(self, FreqDist)
 
         if cond_samples:
-            for (cond, sample) in cond_samples:
+            for cond, sample in cond_samples:
                 self[cond][sample] += 1
 
     def __reduce__(self):
@@ -1927,7 +1927,7 @@ class ConditionalFreqDist(defaultdict):
         cumulative=False,
         percents=False,
         conditions=None,
-        show=True,
+        show=False,
         **kwargs,
     ):
         """
