@@ -2,7 +2,7 @@
 #
 # Author: Dan Garrette <dhgarrette@gmail.com>
 #
-# Copyright (C) 2001-2023 NLTK Project
+# Copyright (C) 2001-2025 NLTK Project
 # URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
@@ -37,17 +37,7 @@ from nltk.sem.logic import (
     is_indvar,
     unique_variable,
 )
-
-# Import Tkinter-based modules if they are available
-try:
-    from tkinter import Canvas, Tk
-    from tkinter.font import Font
-
-    from nltk.util import in_idle
-
-except ImportError:
-    # No need to print a warning here, nltk.draw has already printed one.
-    pass
+from nltk.util import in_idle
 
 
 class DrtTokens(Tokens):
@@ -518,7 +508,7 @@ class DRS(DrtExpression, Expression):
         if isinstance(other, DRS):
             if len(self.refs) == len(other.refs):
                 converted_other = other
-                for (r1, r2) in zip(self.refs, converted_other.refs):
+                for r1, r2 in zip(self.refs, converted_other.refs):
                     varex = self.make_VariableExpression(r1)
                     converted_other = converted_other.replace(r2, varex, True)
                 if self.consequent == converted_other.consequent and len(
@@ -869,7 +859,7 @@ class DrtConcatenation(DrtBooleanExpression):
             other_refs = other.get_refs()
             if len(self_refs) == len(other_refs):
                 converted_other = other
-                for (r1, r2) in zip(self_refs, other_refs):
+                for r1, r2 in zip(self_refs, other_refs):
                     varex = self.make_VariableExpression(r1)
                     converted_other = converted_other.replace(r2, varex, True)
                 return (
@@ -1105,6 +1095,12 @@ class DrsDrawer:
         """
         master = None
         if not canvas:
+
+            # Only import tkinter if the user has indicated that they
+            # want to draw a UI. See issue #2949 for more info.
+            from tkinter import Canvas, Tk
+            from tkinter.font import Font
+
             master = Tk()
             master.title("DRT")
 
@@ -1307,7 +1303,7 @@ class DrsDrawer:
         right = command(DrtTokens.OPEN, right, centred_string_top)[0]
 
         # Handle each arg
-        for (i, arg) in enumerate(args):
+        for i, arg in enumerate(args):
             arg_drawing_top = self._get_centered_top(
                 y, line_height, arg._drawing_height
             )
