@@ -3,8 +3,8 @@
 # Author:     Peter Wang
 # Updated by: Dan Garrette <dhgarrette@gmail.com>
 #
-# Copyright (C) 2001-2015 NLTK Project
-# URL: <http://nltk.org>
+# Copyright (C) 2001-2025 NLTK Project
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 """
@@ -19,18 +19,22 @@ After parsing, the semantic representation is in the form of an underspecified
 representation that is not easy to read.  We use a "plugging" algorithm to
 convert that representation into first-order logic formulas.
 """
-from __future__ import print_function, unicode_literals
 
 from functools import reduce
 
-from nltk import compat
 from nltk.parse import load_parser
-
+from nltk.sem.logic import (
+    AllExpression,
+    AndExpression,
+    ApplicationExpression,
+    ExistsExpression,
+    IffExpression,
+    ImpExpression,
+    LambdaExpression,
+    NegatedExpression,
+    OrExpression,
+)
 from nltk.sem.skolemize import skolemize
-from nltk.sem.logic import (AllExpression, AndExpression, ApplicationExpression,
-                            ExistsExpression, IffExpression, ImpExpression,
-                            LambdaExpression, NegatedExpression, OrExpression)
-
 
 # Note that in this code there may be multiple types of trees being referred to:
 #
@@ -40,30 +44,33 @@ from nltk.sem.logic import (AllExpression, AndExpression, ApplicationExpression,
 # 4. the search space when plugging (search tree)
 #
 
-class Constants(object):
-    ALL = 'ALL'
-    EXISTS = 'EXISTS'
-    NOT = 'NOT'
-    AND = 'AND'
-    OR = 'OR'
-    IMP = 'IMP'
-    IFF = 'IFF'
-    PRED = 'PRED'
-    LEQ = 'LEQ'
-    HOLE = 'HOLE'
-    LABEL = 'LABEL'
 
-    MAP = {ALL: lambda v, e: AllExpression(v.variable, e),
-           EXISTS: lambda v, e: ExistsExpression(v.variable, e),
-           NOT: NegatedExpression,
-           AND: AndExpression,
-           OR: OrExpression,
-           IMP: ImpExpression,
-           IFF: IffExpression,
-           PRED: ApplicationExpression}
+class Constants:
+    ALL = "ALL"
+    EXISTS = "EXISTS"
+    NOT = "NOT"
+    AND = "AND"
+    OR = "OR"
+    IMP = "IMP"
+    IFF = "IFF"
+    PRED = "PRED"
+    LEQ = "LEQ"
+    HOLE = "HOLE"
+    LABEL = "LABEL"
+
+    MAP = {
+        ALL: lambda v, e: AllExpression(v.variable, e),
+        EXISTS: lambda v, e: ExistsExpression(v.variable, e),
+        NOT: NegatedExpression,
+        AND: AndExpression,
+        OR: OrExpression,
+        IMP: ImpExpression,
+        IFF: IffExpression,
+        PRED: ApplicationExpression,
+    }
 
 
-class HoleSemantics(object):
+class HoleSemantics:
     """
     This class holds the broken-down components of a hole semantics, i.e. it
     extracts the holes, labels, logic formula fragments and constraints out of
@@ -71,6 +78,7 @@ class HoleSemantics(object):
     then provides some operations on the semantics dealing with holes, labels
     and finding legal ways to plug holes with labels.
     """
+
     def __init__(self, usr):
         """
         Constructor.  `usr' is a ``sem.Expression`` representing an
@@ -129,7 +137,7 @@ class HoleSemantics(object):
 
     def _find_top_nodes(self, node_list):
         top_nodes = node_list.copy()
-        for f in compat.itervalues(self.fragments):
+        for f in self.fragments.values():
             # the label is the first argument of the predicate
             args = f[1]
             for arg in args:
@@ -182,7 +190,9 @@ class HoleSemantics(object):
             (node, ancestors) = queue[0]
             if node in self.holes:
                 # The node is a hole, try to plug it.
-                self._plug_hole(node, ancestors, queue[1:], potential_labels, plug_acc, record)
+                self._plug_hole(
+                    node, ancestors, queue[1:], potential_labels, plug_acc, record
+                )
             else:
                 assert node in self.labels
                 # The node is a label.  Replace it in the queue by the holes and
@@ -191,10 +201,9 @@ class HoleSemantics(object):
                 head = [(a, ancestors) for a in args if self.is_node(a)]
                 self._plug_nodes(head + queue[1:], potential_labels, plug_acc, record)
         else:
-            raise Exception('queue empty')
+            raise Exception("queue empty")
 
-    def _plug_hole(self, hole, ancestors0, queue, potential_labels0,
-                   plug_acc0, record):
+    def _plug_hole(self, hole, ancestors0, queue, potential_labels0, plug_acc0, record):
         """
         Try all possible ways of plugging a single hole.
         See _plug_nodes for the meanings of the parameters.
@@ -233,7 +242,9 @@ class HoleSemantics(object):
                 # before filling level i+1.
                 # A depth-first search would work as well since the trees must
                 # be finite but the bookkeeping would be harder.
-                self._plug_nodes(queue + [(l, ancestors)], potential_labels, plug_acc, record)
+                self._plug_nodes(
+                    queue + [(l, ancestors)], potential_labels, plug_acc, record
+                )
 
     def _violates_constraints(self, label, ancestors):
         """
@@ -285,12 +296,12 @@ class HoleSemantics(object):
             return node
 
 
-@compat.python_2_unicode_compatible
-class Constraint(object):
+class Constraint:
     """
     This class represents a constraint of the form (L =< N),
     where L is a label and N is a node (a label or a hole).
     """
+
     def __init__(self, lhs, rhs):
         self.lhs = lhs
         self.rhs = rhs
@@ -308,15 +319,15 @@ class Constraint(object):
         return hash(repr(self))
 
     def __repr__(self):
-        return '(%s < %s)' % (self.lhs, self.rhs)
+        return f"({self.lhs} < {self.rhs})"
 
 
 def hole_readings(sentence, grammar_filename=None, verbose=False):
     if not grammar_filename:
-        grammar_filename = 'grammars/sample_grammars/hole.fcfg'
+        grammar_filename = "grammars/sample_grammars/hole.fcfg"
 
     if verbose:
-        print('Reading grammar file', grammar_filename)
+        print("Reading grammar file", grammar_filename)
 
     parser = load_parser(grammar_filename)
 
@@ -324,16 +335,16 @@ def hole_readings(sentence, grammar_filename=None, verbose=False):
     tokens = sentence.split()
     trees = list(parser.parse(tokens))
     if verbose:
-        print('Got %d different parses' % len(trees))
+        print("Got %d different parses" % len(trees))
 
     all_readings = []
     for tree in trees:
         # Get the semantic feature from the top of the parse tree.
-        sem = tree.label()['SEM'].simplify()
+        sem = tree.label()["SEM"].simplify()
 
         # Print the raw semantic representation.
         if verbose:
-            print('Raw:       ', sem)
+            print("Raw:       ", sem)
 
         # Skolemize away all quantifiers.  All variables become unique.
         while isinstance(sem, LambdaExpression):
@@ -341,7 +352,7 @@ def hole_readings(sentence, grammar_filename=None, verbose=False):
         skolemized = skolemize(sem)
 
         if verbose:
-            print('Skolemized:', skolemized)
+            print("Skolemized:", skolemized)
 
         # Break the hole semantics representation down into its components
         # i.e. holes, labels, formula fragments and constraints.
@@ -349,14 +360,14 @@ def hole_readings(sentence, grammar_filename=None, verbose=False):
 
         # Maybe show the details of the semantic representation.
         if verbose:
-            print('Holes:       ', hole_sem.holes)
-            print('Labels:      ', hole_sem.labels)
-            print('Constraints: ', hole_sem.constraints)
-            print('Top hole:    ', hole_sem.top_hole)
-            print('Top labels:  ', hole_sem.top_most_labels)
-            print('Fragments:')
+            print("Holes:       ", hole_sem.holes)
+            print("Labels:      ", hole_sem.labels)
+            print("Constraints: ", hole_sem.constraints)
+            print("Top hole:    ", hole_sem.top_hole)
+            print("Top labels:  ", hole_sem.top_most_labels)
+            print("Fragments:")
             for l, f in hole_sem.fragments.items():
-                print('\t%s: %s' % (l, f))
+                print(f"\t{l}: {f}")
 
         # Find all the possible ways to plug the formulas together.
         pluggings = hole_sem.pluggings()
@@ -368,7 +379,7 @@ def hole_readings(sentence, grammar_filename=None, verbose=False):
         if verbose:
             for i, r in enumerate(readings):
                 print()
-                print('%d. %s' % (i, r))
+                print("%d. %s" % (i, r))
             print()
 
         all_readings.extend(readings)
@@ -376,9 +387,9 @@ def hole_readings(sentence, grammar_filename=None, verbose=False):
     return all_readings
 
 
-if __name__ == '__main__':
-    for r in hole_readings('a dog barks'):
+if __name__ == "__main__":
+    for r in hole_readings("a dog barks"):
         print(r)
     print()
-    for r in hole_readings('every girl chases a dog'):
+    for r in hole_readings("every girl chases a dog"):
         print(r)
