@@ -1,10 +1,9 @@
-# -*- coding: utf-8 -*-
 # Natural Language Toolkit: Twitter API
 #
-# Copyright (C) 2001-2019 NLTK Project
+# Copyright (C) 2001-2025 NLTK Project
 # Author: Ewan Klein <ewan@inf.ed.ac.uk>
 #         Lorenzo Rubio <lrnzcig@gmail.com>
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 """
@@ -14,11 +13,7 @@ handling.
 
 import time as _time
 from abc import ABCMeta, abstractmethod
-from datetime import tzinfo, timedelta, datetime
-
-from six import add_metaclass
-
-from nltk.compat import UTC
+from datetime import datetime, timedelta, timezone, tzinfo
 
 
 class LocalTimezoneOffsetWithUTC(tzinfo):
@@ -51,8 +46,7 @@ class LocalTimezoneOffsetWithUTC(tzinfo):
 LOCAL = LocalTimezoneOffsetWithUTC()
 
 
-@add_metaclass(ABCMeta)
-class BasicTweetHandler(object):
+class BasicTweetHandler(metaclass=ABCMeta):
     """
     Minimal implementation of `TweetHandler`.
 
@@ -129,9 +123,9 @@ class TweetHandlerI(BasicTweetHandler):
         Validate date limits.
         """
         if self.upper_date_limit or self.lower_date_limit:
-            date_fmt = '%a %b %d %H:%M:%S +0000 %Y'
-            tweet_date = datetime.strptime(data['created_at'], date_fmt).replace(
-                tzinfo=UTC
+            date_fmt = "%a %b %d %H:%M:%S +0000 %Y"
+            tweet_date = datetime.strptime(data["created_at"], date_fmt).replace(
+                tzinfo=timezone.utc
             )
             if (self.upper_date_limit and tweet_date > self.upper_date_limit) or (
                 self.lower_date_limit and tweet_date < self.lower_date_limit
@@ -144,7 +138,7 @@ class TweetHandlerI(BasicTweetHandler):
                     date_limit = self.lower_date_limit
                 if verbose:
                     print(
-                        "Date limit {0} is {1} than date of current tweet {2}".format(
+                        "Date limit {} is {} than date of current tweet {}".format(
                             date_limit, message, tweet_date
                         )
                     )
