@@ -1,18 +1,18 @@
-# -*- coding: utf-8 -*-
 # Natural Language Toolkit: Twitter client
 #
-# Copyright (C) 2001-2020 NLTK Project
+# Copyright (C) 2001-2025 NLTK Project
 # Author: Ewan Klein <ewan@inf.ed.ac.uk>
 #         Lorenzo Rubio <lrnzcig@gmail.com>
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 """
-Authentication utilities to accompany :module:`twitterclient`.
+Authentication utilities to accompany `twitterclient`.
 """
 
 import os
 import pprint
+
 from twython import Twython
 
 
@@ -25,7 +25,7 @@ def credsfromfile(creds_file=None, subdir=None, verbose=False):
     )
 
 
-class Authenticate(object):
+class Authenticate:
     """
     Methods for authenticating with Twitter.
     """
@@ -46,25 +46,22 @@ class Authenticate(object):
         """
         Read OAuth credentials from a text file.
 
-        ::
-           File format for OAuth 1
-           =======================
+        File format for OAuth 1::
+
            app_key=YOUR_APP_KEY
            app_secret=YOUR_APP_SECRET
            oauth_token=OAUTH_TOKEN
            oauth_token_secret=OAUTH_TOKEN_SECRET
 
 
-        ::
-           File format for OAuth 2
-           =======================
+        File format for OAuth 2::
 
            app_key=YOUR_APP_KEY
            app_secret=YOUR_APP_SECRET
            access_token=ACCESS_TOKEN
 
-        :param str file_name: File containing credentials. ``None`` (default) reads\
-        data from `TWITTER/'credentials.txt'`
+        :param str file_name: File containing credentials. ``None`` (default) reads
+            data from `TWITTER/'credentials.txt'`
         """
         if creds_file is not None:
             self.creds_file = creds_file
@@ -84,11 +81,11 @@ class Authenticate(object):
         )
 
         if not os.path.isfile(self.creds_fullpath):
-            raise OSError("Cannot find file {}".format(self.creds_fullpath))
+            raise OSError(f"Cannot find file {self.creds_fullpath}")
 
         with open(self.creds_fullpath) as infile:
             if verbose:
-                print("Reading credentials file {}".format(self.creds_fullpath))
+                print(f"Reading credentials file {self.creds_fullpath}")
 
             for line in infile:
                 if "=" in line:
@@ -111,11 +108,11 @@ class Authenticate(object):
             oauth2 = True
 
         if not (oauth1 or oauth2):
-            msg = "Missing or incorrect entries in {}\n".format(self.creds_file)
+            msg = f"Missing or incorrect entries in {self.creds_file}\n"
             msg += pprint.pformat(self.oauth)
             raise ValueError(msg)
         elif verbose:
-            print('Credentials file "{}" looks good'.format(self.creds_file))
+            print(f'Credentials file "{self.creds_file}" looks good')
 
 
 def add_access_token(creds_file=None):
@@ -132,7 +129,7 @@ def add_access_token(creds_file=None):
 
     twitter = Twython(app_key, app_secret, oauth_version=2)
     access_token = twitter.obtain_access_token()
-    tok = "access_token={}\n".format(access_token)
+    tok = f"access_token={access_token}\n"
     with open(creds_file, "a") as infile:
         print(tok, file=infile)
 
