@@ -1,17 +1,17 @@
 # Natural Language Toolkit: Utility functions
 #
-# Copyright (C) 2001-2022 NLTK Project
+# Copyright (C) 2001-2025 NLTK Project
 # Author: Steven Bird <stevenbird1@gmail.com>
 #         Eric Kafe <kafe.eric@gmail.com> (acyclic closures)
 # URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
-
 import inspect
 import locale
 import os
 import pydoc
 import re
 import textwrap
+import unicodedata
 import warnings
 from collections import defaultdict, deque
 from itertools import chain, combinations, islice, tee
@@ -42,7 +42,7 @@ def usage(obj):
         obj = obj.__class__
 
     print(f"{obj.__name__} supports the following operations:")
-    for (name, method) in sorted(pydoc.allmethods(obj).items()):
+    for name, method in sorted(pydoc.allmethods(obj).items()):
         if name.startswith("_"):
             continue
         if getattr(method, "__deprecated__", False):
@@ -139,6 +139,41 @@ def tokenwrap(tokens, separator=" ", width=70):
     return "\n".join(textwrap.wrap(separator.join(tokens), width=width))
 
 
+def cut_string(s, width=70):
+    """
+    Cut off and return a given width of a string
+
+    Return the same as s[:width] if width >= 0 or s[-width:] if
+    width < 0, as long as s has no unicode combining characters.
+    If it has combining characters make sure the returned string's
+    visible width matches the called-for width.
+
+    :param s: the string to cut
+    :type s: str
+    :param width: the display_width
+    :type width: int
+    """
+    chars_sofar = 0
+    width_sofar = 0
+    result = ""
+
+    abs_width = abs(width)
+    max_chars = len(s)
+    while width_sofar < abs_width and chars_sofar < max_chars:
+        if width < 0:
+            char = s[-(chars_sofar + 1)]
+            result = char + result
+        else:
+            char = s[chars_sofar]
+            result = result + char
+
+        chars_sofar += 1
+        if not unicodedata.combining(char):
+            width_sofar += 1
+
+    return result
+
+
 ##########################################################################
 # Indexing
 ##########################################################################
@@ -179,6 +214,7 @@ def re_show(regexp, string, left="{", right="}"):
 # READ FROM FILE OR STRING
 ##########################################################################
 
+
 # recipe from David Mertz
 def filestring(f):
     if hasattr(f, "read"):
@@ -221,7 +257,13 @@ def breadth_first(tree, children=iter, maxdepth=-1):
 
 
 def edge_closure(tree, children=iter, maxdepth=-1, verbose=False):
-    """Yield the edges of a graph in breadth-first order,
+    """
+    :param tree: the tree root
+    :param children: a function taking as argument a tree node
+    :param maxdepth: to limit the search depth
+    :param verbose: to print warnings when cycles are discarded
+
+    Yield the edges of a graph in breadth-first order,
     discarding eventual cycles.
     The first argument should be the start node;
     children should be a function taking as argument a graph node
@@ -259,13 +301,13 @@ def edge_closure(tree, children=iter, maxdepth=-1, verbose=False):
 def edges2dot(edges, shapes=None, attr=None):
     """
     :param edges: the set (or list) of edges of a directed graph.
-
-    :return dot_string: a representation of 'edges' as a string in the DOT
-        graph language, which can be converted to an image by the 'dot' program
-        from the Graphviz package, or nltk.parse.dependencygraph.dot2img(dot_string).
-
     :param shapes: dictionary of strings that trigger a specified shape.
     :param attr: dictionary with global graph attributes
+    :return: a representation of 'edges' as a string in the DOT graph language.
+
+    Returns dot_string: a representation of 'edges' as a string in the DOT
+    graph language, which can be converted to an image by the 'dot' program
+    from the Graphviz package, or nltk.parse.dependencygraph.dot2img(dot_string).
 
     >>> import nltk
     >>> from nltk.util import edges2dot
@@ -301,8 +343,12 @@ def edges2dot(edges, shapes=None, attr=None):
 
 def unweighted_minimum_spanning_digraph(tree, children=iter, shapes=None, attr=None):
     """
+    :param tree: the tree root
+    :param children: a function taking as argument a tree node
+    :param shapes: dictionary of strings that trigger a specified shape.
+    :param attr: dictionary with global graph attributes
 
-    Build a Minimum Spanning Tree (MST) of an unweighted graph,
+        Build a Minimum Spanning Tree (MST) of an unweighted graph,
     by traversing the nodes of a tree in breadth-first order,
     discarding eventual cycles.
 
@@ -317,7 +363,7 @@ def unweighted_minimum_spanning_digraph(tree, children=iter, shapes=None, attr=N
     >>> import nltk
     >>> wn=nltk.corpus.wordnet
     >>> from nltk.util import unweighted_minimum_spanning_digraph as umsd
-    >>> print(umsd(wn.synset('bound.a.01'), lambda s:s.also_sees()))
+    >>> print(umsd(wn.synset('bound.a.01'), lambda s:sorted(s.also_sees())))
     digraph G {
     "Synset('bound.a.01')" -> "Synset('unfree.a.02')";
     "Synset('unfree.a.02')" -> "Synset('confined.a.02')";
@@ -341,8 +387,16 @@ def unweighted_minimum_spanning_digraph(tree, children=iter, shapes=None, attr=N
 ##########################################################################
 
 
-def acyclic_breadth_first(tree, children=iter, maxdepth=-1):
-    """Traverse the nodes of a tree in breadth-first order,
+def acyclic_breadth_first(tree, children=iter, maxdepth=-1, verbose=False):
+    """
+    :param tree: the tree root
+    :param children: a function taking as argument a tree node
+    :param maxdepth: to limit the search depth
+    :param verbose: to print warnings when cycles are discarded
+    :return: the tree in breadth-first order
+
+        Adapted from breadth_first() above, to discard cycles.
+    Traverse the nodes of a tree in breadth-first order,
     discarding eventual cycles.
 
     The first argument should be the tree root;
@@ -353,6 +407,8 @@ def acyclic_breadth_first(tree, children=iter, maxdepth=-1):
     queue = deque([(tree, 0)])
     while queue:
         node, depth = queue.popleft()
+        if node in traversed:
+            continue
         yield node
         traversed.add(node)
         if depth != maxdepth:
@@ -360,7 +416,7 @@ def acyclic_breadth_first(tree, children=iter, maxdepth=-1):
                 for child in children(node):
                     if child not in traversed:
                         queue.append((child, depth + 1))
-                    else:
+                    elif verbose:
                         warnings.warn(
                             "Discarded redundant search for {} at depth {}".format(
                                 child, depth + 1
@@ -371,11 +427,21 @@ def acyclic_breadth_first(tree, children=iter, maxdepth=-1):
                 pass
 
 
-def acyclic_depth_first(tree, children=iter, depth=-1, cut_mark=None, traversed=None):
-    """Traverse the nodes of a tree in depth-first order,
+def acyclic_depth_first(
+    tree, children=iter, depth=-1, cut_mark=None, traversed=None, verbose=False
+):
+    """
+    :param tree: the tree root
+    :param children: a function taking as argument a tree node
+    :param depth: the maximum depth of the search
+    :param cut_mark: the mark to add when cycles are truncated
+    :param traversed: the set of traversed nodes
+    :param verbose: to print warnings when cycles are discarded
+    :return: the tree in depth-first order
+
+    Traverse the nodes of a tree in depth-first order,
     discarding eventual cycles within any branch,
     adding cut_mark (when specified) if cycles were truncated.
-
     The first argument should be the tree root;
     children should be a function taking as argument a tree node
     and returning an iterator of the node's children.
@@ -386,7 +452,7 @@ def acyclic_depth_first(tree, children=iter, depth=-1, cut_mark=None, traversed=
     >>> from nltk.util import acyclic_depth_first as acyclic_tree
     >>> wn=nltk.corpus.wordnet
     >>> from pprint import pprint
-    >>> pprint(acyclic_tree(wn.synset('dog.n.01'), lambda s:s.hypernyms(),cut_mark='...'))
+    >>> pprint(acyclic_tree(wn.synset('dog.n.01'), lambda s:sorted(s.hypernyms()),cut_mark='...'))
     [Synset('dog.n.01'),
      [Synset('canine.n.02'),
       [Synset('carnivore.n.01'),
@@ -418,12 +484,13 @@ def acyclic_depth_first(tree, children=iter, depth=-1, cut_mark=None, traversed=
                         )
                     ]
                 else:
-                    warnings.warn(
-                        "Discarded redundant search for {} at depth {}".format(
-                            child, depth - 1
-                        ),
-                        stacklevel=3,
-                    )
+                    if verbose:
+                        warnings.warn(
+                            "Discarded redundant search for {} at depth {}".format(
+                                child, depth - 1
+                            ),
+                            stacklevel=3,
+                        )
                     if cut_mark:
                         out_tree += [f"Cycle({child},{depth - 1},{cut_mark})"]
         except TypeError:
@@ -434,9 +501,19 @@ def acyclic_depth_first(tree, children=iter, depth=-1, cut_mark=None, traversed=
 
 
 def acyclic_branches_depth_first(
-    tree, children=iter, depth=-1, cut_mark=None, traversed=None
+    tree, children=iter, depth=-1, cut_mark=None, traversed=None, verbose=False
 ):
-    """Traverse the nodes of a tree in depth-first order,
+    """
+    :param tree: the tree root
+    :param children: a function taking as argument a tree node
+    :param depth: the maximum depth of the search
+    :param cut_mark: the mark to add when cycles are truncated
+    :param traversed: the set of traversed nodes
+    :param verbose: to print warnings when cycles are discarded
+    :return: the tree in depth-first order
+
+        Adapted from acyclic_depth_first() above, to
+    traverse the nodes of a tree in depth-first order,
     discarding eventual cycles within the same branch,
     but keep duplicate paths in different branches.
     Add cut_mark (when defined) if cycles were truncated.
@@ -452,7 +529,7 @@ def acyclic_branches_depth_first(
     >>> from nltk.util import acyclic_branches_depth_first as tree
     >>> wn=nltk.corpus.wordnet
     >>> from pprint import pprint
-    >>> pprint(tree(wn.synset('certified.a.01'), lambda s:s.also_sees(), cut_mark='...', depth=4))
+    >>> pprint(tree(wn.synset('certified.a.01'), lambda s:sorted(s.also_sees()), cut_mark='...', depth=4))
     [Synset('certified.a.01'),
      [Synset('authorized.a.01'),
       [Synset('lawful.a.01'),
@@ -491,12 +568,13 @@ def acyclic_branches_depth_first(
                         )
                     ]
                 else:
-                    warnings.warn(
-                        "Discarded redundant search for {} at depth {}".format(
-                            child, depth - 1
-                        ),
-                        stacklevel=3,
-                    )
+                    if verbose:
+                        warnings.warn(
+                            "Discarded redundant search for {} at depth {}".format(
+                                child, depth - 1
+                            ),
+                            stacklevel=3,
+                        )
                     if cut_mark:
                         out_tree += [f"Cycle({child},{depth - 1},{cut_mark})"]
         except TypeError:
@@ -507,7 +585,11 @@ def acyclic_branches_depth_first(
 
 
 def acyclic_dic2tree(node, dic):
-    """Convert acyclic dictionary 'dic', where the keys are nodes, and the
+    """
+    :param node: the root node
+    :param dic: the dictionary of children
+
+    Convert acyclic dictionary 'dic', where the keys are nodes, and the
     values are lists of children, to output tree suitable for pprint(),
     starting at root 'node', with subtrees as nested lists."""
     return [node] + [acyclic_dic2tree(child, dic) for child in dic[node]]
@@ -515,7 +597,10 @@ def acyclic_dic2tree(node, dic):
 
 def unweighted_minimum_spanning_dict(tree, children=iter):
     """
-    Output a dictionary representing a Minimum Spanning Tree (MST)
+    :param tree: the tree root
+    :param children: a function taking as argument a tree node
+
+            Output a dictionary representing a Minimum Spanning Tree (MST)
     of an unweighted graph, by traversing the nodes of a tree in
     breadth-first order, discarding eventual cycles.
 
@@ -527,7 +612,7 @@ def unweighted_minimum_spanning_dict(tree, children=iter):
     >>> from nltk.corpus import wordnet as wn
     >>> from nltk.util import unweighted_minimum_spanning_dict as umsd
     >>> from pprint import pprint
-    >>> pprint(umsd(wn.synset('bound.a.01'), lambda s:s.also_sees()))
+    >>> pprint(umsd(wn.synset('bound.a.01'), lambda s:sorted(s.also_sees())))
     {Synset('bound.a.01'): [Synset('unfree.a.02')],
      Synset('classified.a.02'): [],
      Synset('confined.a.02'): [],
@@ -557,7 +642,10 @@ def unweighted_minimum_spanning_dict(tree, children=iter):
 
 def unweighted_minimum_spanning_tree(tree, children=iter):
     """
-    Output a Minimum Spanning Tree (MST) of an unweighted graph,
+    :param tree: the tree root
+    :param children: a function taking as argument a tree node
+
+       Output a Minimum Spanning Tree (MST) of an unweighted graph,
     by traversing the nodes of a tree in breadth-first order,
     discarding eventual cycles.
 
@@ -569,7 +657,7 @@ def unweighted_minimum_spanning_tree(tree, children=iter):
     >>> from nltk.util import unweighted_minimum_spanning_tree as mst
     >>> wn=nltk.corpus.wordnet
     >>> from pprint import pprint
-    >>> pprint(mst(wn.synset('bound.a.01'), lambda s:s.also_sees()))
+    >>> pprint(mst(wn.synset('bound.a.01'), lambda s:sorted(s.also_sees())))
     [Synset('bound.a.01'),
      [Synset('unfree.a.02'),
       [Synset('confined.a.02')],
@@ -858,14 +946,15 @@ def ngrams(sequence, n, **kwargs):
     """
     sequence = pad_sequence(sequence, n, **kwargs)
 
-    # Creates the sliding window, of n no. of items.
-    # `iterables` is a tuple of iterables where each iterable is a window of n items.
-    iterables = tee(sequence, n)
-
-    for i, sub_iterable in enumerate(iterables):  # For each window,
-        for _ in range(i):  # iterate through every order of ngrams
-            next(sub_iterable, None)  # generate the ngrams within the window.
-    return zip(*iterables)  # Unpack and flattens the iterables.
+    # sliding_window('ABCDEFG', 4) --> ABCD BCDE CDEF DEFG
+    # https://docs.python.org/3/library/itertools.html?highlight=sliding_window#itertools-recipes
+    it = iter(sequence)
+    window = deque(islice(it, n), maxlen=n)
+    if len(window) == n:
+        yield tuple(window)
+    for x in it:
+        window.append(x)
+        yield tuple(window)
 
 
 def bigrams(sequence, **kwargs):
@@ -1009,6 +1098,7 @@ def skipgrams(sequence, n, k, **kwargs):
 # Binary Search in a File
 ######################################################################
 
+
 # inherited from pywordnet, by Oliver Steele
 def binary_search_file(file, key, cache=None, cacheDepth=-1):
     """
