@@ -3,14 +3,14 @@
 # Authors: Liling Tan <alvations@gmail.com>,
 #          Dmitrijs Milajevs <dimazest@gmail.com>
 #
-# Copyright (C) 2001-2022 NLTK Project
+# Copyright (C) 2001-2025 NLTK Project
 # URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 from nltk.corpus import wordnet
 
 
-def lesk(context_sentence, ambiguous_word, pos=None, synsets=None):
+def lesk(context_sentence, ambiguous_word, pos=None, synsets=None, lang="eng"):
     """Return a synset for an ambiguous word in a context.
 
     :param iter context_sentence: The context sentence where the ambiguous word
@@ -18,6 +18,7 @@ def lesk(context_sentence, ambiguous_word, pos=None, synsets=None):
     :param str ambiguous_word: The ambiguous word that requires WSD.
     :param str pos: A specified Part-of-Speech (POS).
     :param iter synsets: Possible synsets of the ambiguous word.
+    :param str lang: WordNet language.
     :return: ``lesk_sense`` The Synset() object with the highest signature overlaps.
 
     This function is an implementation of the original Lesk algorithm (1986) [1].
@@ -25,7 +26,7 @@ def lesk(context_sentence, ambiguous_word, pos=None, synsets=None):
     Usage example::
 
         >>> lesk(['I', 'went', 'to', 'the', 'bank', 'to', 'deposit', 'money', '.'], 'bank', 'n')
-        Synset('savings_bank.n.02')
+        Synset('depository_financial_institution.n.01')
 
     [1] Lesk, Michael. "Automatic sense disambiguation using machine
     readable dictionaries: how to tell a pine cone from an ice cream
@@ -36,7 +37,7 @@ def lesk(context_sentence, ambiguous_word, pos=None, synsets=None):
 
     context = set(context_sentence)
     if synsets is None:
-        synsets = wordnet.synsets(ambiguous_word)
+        synsets = wordnet.synsets(ambiguous_word, lang=lang)
 
     if pos:
         synsets = [ss for ss in synsets if str(ss.pos()) == pos]
@@ -44,8 +45,8 @@ def lesk(context_sentence, ambiguous_word, pos=None, synsets=None):
     if not synsets:
         return None
 
-    _, sense = max(
-        (len(context.intersection(ss.definition().split())), ss) for ss in synsets
+    sense = max(
+        synsets, key=lambda ss: len(context.intersection(ss.definition().split()))
     )
 
     return sense
